* Encoding: UTF-8.

FILE HANDLE dataDirectory /NAME='C:\Users\user\Downloads'.

*==================================.
* COMPUTE INTERRATER AGREEMENT.
*==================================.

*Get data.
GET FILE = "dataDirectory\Ratings.sav".
DATASET NAME Ratings.

* Exclude invalid ratings/cases (N=5).
DATASET ACTIVATE Ratings.
USE ALL.
FREQUENCIES VARIABLES=Exclusion_criteria.
COMPUTE filter_$=(Retraction_ID > 0).
VARIABLE LABELS filter_$ 'Retraction_ID > 0 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

* Compute.Interrater agreement: 100*(number of agreeing values / number of all coded values).
DO IF (RaterA_RetReason EQ RaterB_RetReason).
Compute Agreement = 1.
ELSE.
Compute Agreement = 0.
END IF.
FREQUENCIES VARIABLES=Agreement
  /ORDER=ANALYSIS.

DATASET CLOSE Ratings.


*==================================.
* FREQUENCIES: MISCONDUCT, RETRACTION REASONS.
*==================================.
*Get data.
GET FILE = "dataDirectory\Retraction_Cases.sav".
DATASET NAME Cases.

DATASET ACTIVATE Cases.
USE ALL.
COMPUTE Misconduct = ( Reason = 1 |  Reason = 2 | Reason = 3).
VARIABLE LABELS Misconduct 'Article retracted due to misconduct (FILTER)'.
VALUE LABELS Misconduct 0 'No' 1 'Yes'.
FORMATS Misconduct (f1.0).

FREQUENCIES VARIABLES=Reason
  /ORDER=ANALYSIS.
FREQUENCIES VARIABLES=Misconduct
  /ORDER=ANALYSIS.

*==================================.
* FOR FURTHER ANALYSES SELECT RETRACTIONS DUE TO MISCONDUCT (RATING CATEGORIES 1-3).
*==================================.
 
FILTER BY Misconduct.
EXECUTE.

*==================================.
* GET TOTAL NUMBER OF PUBLISHED ARTICLES AND COMPUTE TOTAL PREVALENCE WITH 260 ARTICLES RETRACTED DUE TO MISCONDUCT.
*==================================.

*Get data.
GET FILE = "dataDirectory\Baserates_per_year.sav".
DATASET NAME Baserates.

DATASET ACTIVATE Baserates.
DATASET DECLARE Temp.
AGGREGATE
  /OUTFILE='Temp'
  /BREAK=
  /Total_Articles=SUM(N_Articles).

DATASET ACTIVATE Temp.
COMPUTE Total_Prevalenz=10000*(260/Total_Articles).
List Variables=Total_Articles Total_Prevalenz.

DATASET Close Temp.
DATASET Close Baserates.


*==================================.
* RETRACTED ARTICLES PER YEAR.
*==================================.

*Get data.
GET FILE = "dataDirectory\Baserates_per_year.sav".
DATASET NAME Baserates.

* Compute number of retracted articles due to misconduct (N_Retracted) per publication year of retracted article.
DATASET ACTIVATE Cases.
DATASET DECLARE MisconductByYear.
AGGREGATE
  /OUTFILE='MisconductByYear'
  /BREAK=YR
  /N_Retracted=N.

* Add number of retracted articles due to misconduct (N_Retracted) to number of articles published per year.
DATASET ACTIVATE Baserates.
DATASET DECLARE Results1.
STAR JOIN
  /SELECT t0.Query, t0.N_Articles, t1.N_Retracted
  /FROM 'Baserates' AS t0
  /JOIN 'MisconductByYear' AS t1
    ON t0.YR=t1.YR
  /OUTFILE FILE=Results1.

DATASET ACTIVATE Results1.
* Computer prevalence rate per year and list results.
COMPUTE Prevalenz=10000*(N_Retracted/N_Articles).
LIST VARIABLES=YR N_Articles N_Retracted Prevalenz.
EXECUTE.

* Close data sets.
DATASET CLOSE Baserates.
DATASET CLOSE MisconductByYear.

*==================================.
* COMPUTING NUMBER OF RETRACTED ARTICLES FOR EACH CONTENT CATEGORY.
* NOTE: SAME ARTICLE CAN COUNT IN TWO CONTENT CATEGORIES.
*==================================.

*Get data.
GET FILE = "dataDirectory\Baserates_per_content_category.sav".
DATASET NAME CC_Baserates.

* For each content category (CC 21 - CC 42) compute if article is a member.
DATASET ACTIVATE Cases.
COMPUTE #counter=20.
DO REPEAT myVar=CC_21 TO CC_42.
COMPUTE myVar = 0.
FORMATS myVar (F1.0).
COMPUTE #counter=#counter+1.
DO IF (CC1 EQ #counter) OR (CC2 EQ #counter).
COMPUTE myVar=1.
END IF.
END REPEAT.
EXECUTE.

* Sum up number of retracted articles in content category and write aggregate values into data set CC.
DATASET DECLARE CC.
AGGREGATE
  /OUTFILE='CC'
  /BREAK=
  /CC21=SUM(CC_21) 
  /CC22=SUM(CC_22) 
  /CC23=SUM(CC_23) 
  /CC24=SUM(CC_24) 
  /CC25=SUM(CC_25) 
  /CC26=SUM(CC_26) 
  /CC27=SUM(CC_27) 
  /CC28=SUM(CC_28) 
  /CC29=SUM(CC_29) 
  /CC30=SUM(CC_30) 
  /CC31=SUM(CC_31) 
  /CC32=SUM(CC_32) 
  /CC33=SUM(CC_33) 
  /CC34=SUM(CC_34) 
  /CC35=SUM(CC_35) 
  /CC36=SUM(CC_36) 
  /CC37=SUM(CC_37) 
  /CC38=SUM(CC_38) 
  /CC39=SUM(CC_39) 
  /CC40=SUM(CC_40) 
  /CC41=SUM(CC_41) 
  /CC42=SUM(CC_42).

/* Transpose data set (colums to rows) .
DATASET ACTIVATE CC.
STRING ColName (A11).
COMPUTE ColName='N_Retracted'.
FLIP VARIABLES=CC21 to CC42 /NEWNAMES=ColName.
DATASET NAME ContentCategories.

* Add number of retracted articles due to misconduct (N_Retracted) to number of articles published in content category.
DATASET ACTIVATE CC_Baserates.
DATASET DECLARE Results2.
STAR JOIN
  /SELECT *
  /FROM 'CC_Baserates' AS t0
  /JOIN 'ContentCategories' AS t1
    ON t0.CC_Code=t1.CASE_LBL
  /OUTFILE FILE=Results2.

* Computer prevalence rate per content category and list results.
DATASET ACTIVATE Results2.
FORMATS N_Retracted (F8.0).
COMPUTE Prevalenz=10000*(N_Retracted/Num_Hits).
SORT CASES BY Prevalenz (D).
LIST VARIABLES=SubjectField N_Retracted Prevalenz .
EXECUTE.

* Close data sets.
DATASET CLOSE CC_Baserates.
DATASET CLOSE CC.
DATASET CLOSE ContentCategories.

*==================================.
* COMPUTING NUMBER OF RETRACTED UNIQUE AUTHORS FOR EACH CONTENT CATEGORY.
* NOTE: SAME AUTHOR(ARTICLE CAN COUNT IN TWO CONTENT CATEGORIES.
*==================================.
*Get data.
GET FILE = "dataDirectory\Baserates_per_content_category.sav".
DATASET NAME CC_Baserates.

/* Code each "Collective" Author into one single (unique)  author.
DATASET ACTIVATE Cases.
STRING Author_recoded (A25).
DO IF (Responsible_Author EQ 'Collective').
COMPUTE Author_recoded = CONCAT(Responsible_Author,STRING(Retraction_ID,N3)).
ELSE.
COMPUTE Author_recoded = Responsible_Author.
END IF.

* Sum up number of retracted articles for each unique author in content category and write aggregate values into data set AuthorsByCC.
DATASET DECLARE AuthorsByCC.
AGGREGATE
  /OUTFILE='AuthorsByCC'
  /BREAK=Author_recoded
  /CC21=SUM(CC_21) 
  /CC22=SUM(CC_22) 
  /CC23=SUM(CC_23) 
  /CC24=SUM(CC_24) 
  /CC25=SUM(CC_25) 
  /CC26=SUM(CC_26) 
  /CC27=SUM(CC_27) 
  /CC28=SUM(CC_28) 
  /CC29=SUM(CC_29) 
  /CC30=SUM(CC_30) 
  /CC31=SUM(CC_31) 
  /CC32=SUM(CC_32) 
  /CC33=SUM(CC_33) 
  /CC34=SUM(CC_34) 
  /CC35=SUM(CC_35) 
  /CC36=SUM(CC_36) 
  /CC37=SUM(CC_37) 
  /CC38=SUM(CC_38) 
  /CC39=SUM(CC_39) 
  /CC40=SUM(CC_40) 
  /CC41=SUM(CC_41) 
  /CC42=SUM(CC_42).

* Sum up number of unique authors with retracted articles in content category and write aggregate values into data set NumAuthors.
DATASET ACTIVATE AuthorsByCC.
DATASET DECLARE NumAuthors.
AGGREGATE
  /OUTFILE='NumAuthors'
  /BREAK=
  /CC21=CGT(CC21,0) 
  /CC22=CGT(CC22,0) 
  /CC23=CGT(CC23,0) 
  /CC24=CGT(CC24,0) 
  /CC25=CGT(CC25,0) 
  /CC26=CGT(CC26,0) 
  /CC27=CGT(CC27,0) 
  /CC28=CGT(CC28,0) 
  /CC29=CGT(CC29,0) 
  /CC30=CGT(CC30,0) 
  /CC31=CGT(CC31,0) 
  /CC32=CGT(CC32,0) 
  /CC33=CGT(CC33,0) 
  /CC34=CGT(CC34,0) 
  /CC35=CGT(CC35,0) 
  /CC36=CGT(CC36,0) 
  /CC37=CGT(CC37,0) 
  /CC38=CGT(CC38,0) 
  /CC39=CGT(CC39,0) 
  /CC40=CGT(CC40,0) 
  /CC41=CGT(CC41,0) 
  /CC42=CGT(CC42,0).

/* Transpose data set NumAuthors (columns to rows) .
DATASET ACTIVATE NumAuthors.
STRING ColName (A25).
COMPUTE ColName='RetractedAuthors'.
FLIP VARIABLES=CC21 to CC42 /NEWNAMES=ColName.
DATASET NAME ContentCategories.

* Add number of  unique authors in content category with retracted articles due to misconduct (RetractedAuthors) to number of articles published .
DATASET ACTIVATE CC_Baserates.
DATASET DECLARE Results3.
STAR JOIN
  /SELECT *
  /FROM 'CC_Baserates' AS t0
  /JOIN 'ContentCategories' AS t1
    ON t0.CC_Code=t1.CASE_LBL
  /OUTFILE FILE=Results3.

DATASET ACTIVATE Results3.
FORMATS RetractedAuthors (F8.0).
COMPUTE PrevalenzAuthors=10000*(RetractedAuthors/Num_Hits).
LIST VARIABLES=SubjectField RetractedAuthors PrevalenzAuthors.
EXECUTE.

* Close data sets no longer used.
DATASET CLOSE CC_Baserates.
DATASET CLOSE AuthorsByCC.
DATASET CLOSE NumAuthors.
DATASET CLOSE ContentCategories.

DATASET CLOSE Cases.

